@@ -20,6 +20,9 @@ FAILEDOPERATION = 'FailedOperation'
 # 重复的订单，请检查emr控制台。
 FAILEDOPERATION_DUPLICATEORDERNOTALLOWED = 'FailedOperation.DuplicateOrderNotAllowed'
 
+# 操作失败，不支持pod。
+FAILEDOPERATION_NOTSUPPORTPOD = 'FailedOperation.NotSupportPod'
+
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
@@ -95,9 +98,6 @@ INVALIDPARAMETER_INCORRECTCOMMONCOUNT = 'InvalidParameter.IncorrectCommonCount'
 # Master节点数量无效。
 INVALIDPARAMETER_INCORRECTMASTERCOUNT = 'InvalidParameter.IncorrectMasterCount'
 
-# core节点的数量不能超过20。
-INVALIDPARAMETER_INVAILDCORECOUNT = 'InvalidParameter.InvaildCoreCount'
-
 # 无效参数，AppId。
 INVALIDPARAMETER_INVALIDAPPID = 'InvalidParameter.InvalidAppId'
 
@@ -113,12 +113,18 @@ INVALIDPARAMETER_INVALIDCLIENTTOKEN = 'InvalidParameter.InvalidClientToken'
 # 无效参数，ClusterId。
 INVALIDPARAMETER_INVALIDCLUSTERID = 'InvalidParameter.InvalidClusterId'
 
+# 参数错误。
+INVALIDPARAMETER_INVALIDCOMMONDISKTYPE = 'InvalidParameter.InvalidCommonDiskType'
+
 # 无效的组件。
 INVALIDPARAMETER_INVALIDCOMPONENT = 'InvalidParameter.InvalidComponent'
 
 # Core节点数量无效。
 INVALIDPARAMETER_INVALIDCORECOUNT = 'InvalidParameter.InvalidCoreCount'
 
+# CosFileUri参数值无效。
+INVALIDPARAMETER_INVALIDCOSFILEURI = 'InvalidParameter.InvalidCosFileURI'
+
 # 扩容数量必须大于0。
 INVALIDPARAMETER_INVALIDCOUNT = 'InvalidParameter.InvalidCount'
 
@@ -161,6 +167,9 @@ INVALIDPARAMETER_INVALIDJOBTYPE = 'InvalidParameter.InvalidJobType'
 # 无效的登录设置。
 INVALIDPARAMETER_INVALIDLOGINSETTING = 'InvalidParameter.InvalidLoginSetting'
 
+# 参数错误。
+INVALIDPARAMETER_INVALIDMASTERDISKTYPE = 'InvalidParameter.InvalidMasterDiskType'
+
 # 无效的元数据表类型。
 INVALIDPARAMETER_INVALIDMETATYPE = 'InvalidParameter.InvalidMetaType'
 
@@ -224,6 +233,9 @@ INVALIDPARAMETER_INVALIDSUBNETID = 'InvalidParameter.InvalidSubnetId'
 # 无效的高可用参数。
 INVALIDPARAMETER_INVALIDSUPPORTHA = 'InvalidParameter.InvalidSupportHA'
 
+# 参数错误。
+INVALIDPARAMETER_INVALIDTAGSGROUP = 'InvalidParameter.InvalidTagsGroup'
+
 # task的数量不能超过20。
 INVALIDPARAMETER_INVALIDTASKCOUNT = 'InvalidParameter.InvalidTaskCount'
 
@@ -314,11 +326,8 @@ RESOURCENOTFOUND_TAGSNOTFOUND = 'ResourceNotFound.TagsNotFound'
 # 当前资源规格不存在默认规格。
 RESOURCEUNAVAILABLE_RESOURCESPECNOTDEFAULTSPEC = 'ResourceUnavailable.ResourceSpecNotDefaultSpec'
 
-# 当前资源规格不存在默认规格。
-RESOURCEUNAVAILABLE_RESOURCESPEC_NOTDEFAULTSPEC = 'ResourceUnavailable.ResourceSpec_NotDefaultSpec'
-
 # 资源售罄。
-RESOURCESSOLDOUT_ = 'ResourcesSoldOut.'
+RESOURCESSOLDOUT = 'ResourcesSoldOut'
 
 # CBS资源售罄。
 RESOURCESSOLDOUT_CBSSOLDOUT = 'ResourcesSoldOut.CbsSoldOut'
