@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -36,7 +36,8 @@ class OceanusClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateJob", params)
+            headers = request.headers
+            body = self.call("CreateJob", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateJobResponse()
@@ -64,7 +65,8 @@ class OceanusClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateJobConfig", params)
+            headers = request.headers
+            body = self.call("CreateJobConfig", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateJobConfigResponse()
@@ -92,7 +94,8 @@ class OceanusClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateResource", params)
+            headers = request.headers
+            body = self.call("CreateResource", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateResourceResponse()
@@ -120,7 +123,8 @@ class OceanusClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateResourceConfig", params)
+            headers = request.headers
+            body = self.call("CreateResourceConfig", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateResourceConfigResponse()
@@ -138,6 +142,64 @@ class OceanusClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeleteResourceConfigs(self, request):
+        """删除资源版本
+
+        :param request: Request instance for DeleteResourceConfigs.
+        :type request: :class:`tencentcloud.oceanus.v20190422.models.DeleteResourceConfigsRequest`
+        :rtype: :class:`tencentcloud.oceanus.v20190422.models.DeleteResourceConfigsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteResourceConfigs", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeleteResourceConfigsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DeleteResources(self, request):
+        """删除资源接口
+
+        :param request: Request instance for DeleteResources.
+        :type request: :class:`tencentcloud.oceanus.v20190422.models.DeleteResourcesRequest`
+        :rtype: :class:`tencentcloud.oceanus.v20190422.models.DeleteResourcesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteResources", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeleteResourcesResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DeleteTableConfig(self, request):
         """删除作业表配置
 
@@ -148,7 +210,8 @@ class OceanusClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteTableConfig", params)
+            headers = request.headers
+            body = self.call("DeleteTableConfig", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteTableConfigResponse()
@@ -176,7 +239,8 @@ class OceanusClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeJobConfigs", params)
+            headers = request.headers
+            body = self.call("DescribeJobConfigs", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeJobConfigsResponse()
@@ -204,7 +268,8 @@ class OceanusClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeJobs", params)
+            headers = request.headers
+            body = self.call("DescribeJobs", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeJobsResponse()
@@ -222,6 +287,93 @@ class OceanusClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeResourceConfigs(self, request):
+        """描述资源配置接口
+
+        :param request: Request instance for DescribeResourceConfigs.
+        :type request: :class:`tencentcloud.oceanus.v20190422.models.DescribeResourceConfigsRequest`
+        :rtype: :class:`tencentcloud.oceanus.v20190422.models.DescribeResourceConfigsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeResourceConfigs", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeResourceConfigsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeResourceRelatedJobs(self, request):
+        """获取资源关联作业信息
+
+        :param request: Request instance for DescribeResourceRelatedJobs.
+        :type request: :class:`tencentcloud.oceanus.v20190422.models.DescribeResourceRelatedJobsRequest`
+        :rtype: :class:`tencentcloud.oceanus.v20190422.models.DescribeResourceRelatedJobsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeResourceRelatedJobs", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeResourceRelatedJobsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeResources(self, request):
+        """描述资源接口
+
+        :param request: Request instance for DescribeResources.
+        :type request: :class:`tencentcloud.oceanus.v20190422.models.DescribeResourcesRequest`
+        :rtype: :class:`tencentcloud.oceanus.v20190422.models.DescribeResourcesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeResources", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeResourcesResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeSystemResources(self, request):
         """描述系统资源接口
 
@@ -232,7 +384,8 @@ class OceanusClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeSystemResources", params)
+            headers = request.headers
+            body = self.call("DescribeSystemResources", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeSystemResourcesResponse()
@@ -260,7 +413,8 @@ class OceanusClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("RunJobs", params)
+            headers = request.headers
+            body = self.call("RunJobs", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.RunJobsResponse()
@@ -288,7 +442,8 @@ class OceanusClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("StopJobs", params)
+            headers = request.headers
+            body = self.call("StopJobs", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.StopJobsResponse()
